@@ -1,10 +1,15 @@
+#!/bin/sh
+
+LIBS='-L${libdir} -ltickit'
+CFLAGS='-I${includedir}'
+
 cat <<EOF
 libdir=$LIBDIR
 includedir=$INCDIR
 
 Name: tickit
 Description: Terminal Interface Construction KIT
-Version: 0.2
-Libs: -L\${libdir} -ltickit
-Cflags: -I\${includedir}
+Version: 0.3.4
+Libs: $LIBS
+Cflags: $CFLAGS
 EOF
